"""
German linguistic markers for epistemic detection.
"""

MARKERS = {
    "uncertainty": [
        r"\bich bin mir nicht sicher\b",
        r"\bich weiss nicht\b",
        r"\bich weiß nicht\b",
        r"\bich denke\b",
        r"\bich glaube\b",
        r"\bvielleicht\b",
        r"\bmoeglicherweise\b",
        r"\bmöglicherweise\b",
        r"\bwahrscheinlich\b",
        r"\bkoennte sein\b",
        r"\bkönnte sein\b",
        r"\bunklar\b",
        r"\bunsicher\b",
        r"\bvermutlich\b",
        r"\banscheinend\b",
        r"\bscheint\b",
        r"\bsoweit ich weiss\b",
        r"\bsoweit ich weiß\b",
    ],
    "overconfidence": [
        r"\bdefinitiv\b",
        r"\bsicherlich\b",
        r"\bauf jeden fall\b",
        r"\babsolut\b",
        r"\bimmer\b",
        r"\bnie\b",
        r"\bniemals\b",
        r"\bzweifellos\b",
        r"\boffensichtlich\b",
        r"\bklar\b",
        r"\bgarantiert\b",
        r"100\s?%",
        r"\bgenau\b",
        r"\bpraezise\b",
        r"\bpräzise\b",
        r"\bmuss sein\b",
        r"\bkeine frage\b",
    ],
    "fabrication": [
        r"mein wissensstand",
        r"ich habe keinen zugriff",
        r"als ki\b",
        r"als sprachmodell",
        r"meine trainingsdaten",
    ],
    "unanswerable": [
        r"was wird .+ (wert sein|kosten|sein) in \d{4}",
        r"wer wird gewinnen",
        r"aktien.*(morgen|naechste|nächste)",
        r"\bvorhersage\b",
        r"lotterie",
    ],
}
